@@ -1,10 +1,14 @@
 import os
 import json
 import shutil
-import datamart_profiler
-import pandas as pd
-from datamart_materialize.d3m import D3mWriter
+import logging
 from os.path import join, exists
+from d3m.container import Dataset
+from d3m.utils import fix_uri
+from d3m.container.utils import save_container
+
+logger = logging.getLogger(__name__)
+DATASET_ID = 'internal_dataset'
 
 
 def is_d3m_format(dataset, suffix):
@@ -14,39 +18,28 @@ def is_d3m_format(dataset, suffix):
     return False
 
 
-def convert_d3m_format(dataset, output_folder, problem_config, suffix):
-    print('Reiceving a raw dataset, converting to D3M format')
+def convert_d3m_format(dataset_uri, output_folder, problem_config, suffix):
+    logger.info('Reiceving a raw dataset, converting to D3M format')
     dataset_folder = join(output_folder, 'temp', 'dataset_d3mformat', suffix, 'dataset_%s' % suffix)
     problem_folder = join(output_folder, 'temp', 'dataset_d3mformat', suffix, 'problem_%s' % suffix)
-    create_d3m_problem(dataset, problem_folder, problem_config)
-    create_d3m_dataset(dataset, dataset_folder)
+    dataset = create_d3m_dataset(dataset_uri, dataset_folder)
+    create_d3m_problem(dataset['learningData'], problem_folder, problem_config)
 
     return join(output_folder, 'temp', 'dataset_d3mformat', suffix)
 
 
-def create_d3m_dataset(dataset, destination_path, version='4.0.0'):
-    metadata = datamart_profiler.process_dataset(dataset)
-
+def create_d3m_dataset(dataset_uri, destination_path):
     if exists(destination_path):
         shutil.rmtree(destination_path)
 
-    writer = D3mWriter(
-        dataset_id='internal_dataset',
-        destination=destination_path,
-        metadata=metadata,
-        format_options={'need_d3mindex': True, 'version': version},
-    )
-    with open(dataset, 'rb') as source:
-        with writer.open_file('wb') as dest:
-            shutil.copyfileobj(source, dest)
-    writer.finish()
+    dataset = Dataset.load(fix_uri(dataset_uri), dataset_id=DATASET_ID)
+    save_container(dataset, destination_path)
+
+    return dataset
 
 
 def create_d3m_problem(dataset, destination_path, problem_config):
-    if isinstance(dataset, str):
-        target_index = pd.read_csv(dataset).columns.get_loc(problem_config['target_name'])
-    else:
-        target_index = dataset.columns.get_loc(problem_config['target_name'])
+    target_index = dataset.columns.get_loc(problem_config['target_name'])
     problem_config['target_index'] = target_index
 
     if exists(destination_path):
@@ -60,12 +53,12 @@ def create_d3m_problem(dataset, destination_path, problem_config):
             "problemDescription": "",
             "problemVersion": "4.0.0",
             "problemSchemaVersion": "4.0.0",
-            "taskKeywords": problem_config.get('task_keywords', ["classification", "multiClass"])
+            "taskKeywords": problem_config.get('task_keywords')
           },
           "inputs": {
             "data": [
               {
-                "datasetID": "internal_dataset",
+                "datasetID": DATASET_ID,
                 "targets": [
                   {
                     "targetIndex": 0,
